durationtools.lilypond_duration_string_to_rational_list
=======================================================

.. autofunction:: abjad.tools.durationtools.lilypond_duration_string_to_rational_list.lilypond_duration_string_to_rational_list
